@@ -6,7 +6,7 @@ use base 'Perinci::To::PackageBase::I18N';
 use Locale::Maketext::Lexicon::Gettext;
 our %Lexicon = %{ Locale::Maketext::Lexicon::Gettext->parse(<DATA>) };
 
-our $VERSION = '0.25'; # VERSION
+our $VERSION = '0.26'; # VERSION
 
 #use Data::Dump; dd \%Lexicon;
 
@@ -21,9 +21,23 @@ our $VERSION = '0.25'; # VERSION
 
 Perinci::To::PackageBase::I18N::fr - French translation for Perinci::To::PackageBase
 
-=head1 VERSION
+=head1 HOMEPAGE
 
-version 0.25
+Please visit the project's homepage at
+L<https://metacpan.org/release/Perinci-To-Text>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Text>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-To-Text
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
@@ -36,13 +50,6 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 DESCRIPTION
-
-=head1 FUNCTIONS
-
-
-None are exported by default, but they are exportable.
-
 =cut
 
 __DATA__
